@@ -77,7 +77,7 @@ class RabbitMQDriver(drivers.Driver):
             complete_env.update(self.env)
             c, _ = self._exec(["rabbitmq-server"], env=complete_env,
                               path=self._path,
-                              wait_for_line="Starting broker\.\.\. completed")
+                              wait_for_line=("completed with .* plugins"))
             self.addCleanup(self.kill_node, nodename, ignore_not_exists=True)
             self._process[nodename] = c
         return port
