@@ -31,6 +31,7 @@ from pifpaf.drivers import etcd
 from pifpaf.drivers import fakes3
 from pifpaf.drivers import gnocchi
 from pifpaf.drivers import influxdb
+from pifpaf.drivers import kafka
 from pifpaf.drivers import keystone
 from pifpaf.drivers import memcached
 from pifpaf.drivers import mongodb
@@ -38,6 +39,7 @@ from pifpaf.drivers import mysql
 from pifpaf.drivers import postgresql
 from pifpaf.drivers import rabbitmq
 from pifpaf.drivers import redis
+from pifpaf.drivers import s3rver
 from pifpaf.drivers import zookeeper
 
 
@@ -48,15 +50,20 @@ os.environ["PATH"] = ":".join((
     "/opt/influxdb",
     "/usr/share/elasticsearch/bin",
     "/usr/local/sbin",
+    "/opt/kafka/bin",
 ))
 
 
 class TestDrivers(testtools.TestCase):
     def setUp(self):
         super(TestDrivers, self).setUp()
-        if os.getenv('PIFPAF_DEBUG'):
-            logging.basicConfig(format="%(levelname)8s [%(name)s] %(message)s",
-                                level=logging.DEBUG)
+        self.logger = self.useFixture(
+            fixtures.FakeLogger(
+                format="%(levelname)8s [%(name)s] %(message)s",
+                level=logging.DEBUG,
+                nuke_handlers=True,
+            )
+        )
 
     def _run(self, cmd):
         self.assertEqual(0, os.system(cmd + " >/dev/null 2>&1"))
@@ -145,7 +152,7 @@ class TestDrivers(testtools.TestCase):
                           "s3rver not found")
     def test_s3rver(self):
         port = 4569
-        self.useFixture(fakes3.FakeS3Driver(port=port))
+        self.useFixture(s3rver.S3rverDriver(port=port))
         self.assertEqual("s3://localhost:%d" % port,
                          os.getenv("PIFPAF_URL"))
         self.assertEqual("http://localhost:%d" % port,
@@ -209,8 +216,9 @@ class TestDrivers(testtools.TestCase):
         self.assertEqual("6380", os.getenv("PIFPAF_REDIS_SENTINEL_PORT"))
         self._run("redis-cli -p %d sentinel master pifpaf" % f.sentinel_port)
 
-    @testtools.skipUnless(spawn.find_executable("zkServer"),
-                          "ZooKeeper not found")
+    @testtools.skipUnless(spawn.find_executable(
+        "zkServer.sh", path=":".join(zookeeper.ZooKeeperDriver.PATH)),
+        "ZooKeeper not found")
     def test_zookeeper(self):
         port = 2182
         f = self.useFixture(zookeeper.ZooKeeperDriver(port=port))
@@ -389,3 +397,16 @@ class TestDrivers(testtools.TestCase):
                          os.getenv("PIFPAF_URL"))
         r = requests.get("http://localhost:%d/" % port)
         self.assertEqual(r.json()["couchdb"], "Welcome")
+
+    @testtools.skipUnless(spawn.find_executable("kafka-server-start.sh"),
+                          "Kafka not found")
+    def test_kafka(self):
+        a = self.useFixture(kafka.KafkaDriver(port=54321,
+                                              zookeeper_port=12345))
+        self.assertEqual("kafka://localhost:54321",
+                         os.getenv("PIFPAF_URL"))
+        self.assertEqual(12345, a.zookeeper_port)
+        self.assertEqual("54321", os.getenv("PIFPAF_KAFKA_PORT"))
+        self.assertEqual("PLAINTEXT", os.getenv("PIFPAF_KAFKA_PROTOCOL"))
+        self.assertEqual("PLAINTEXT://localhost:54321",
+                         os.getenv("PIFPAF_KAFKA_URL"))
